==> obs-studio_32.0.4.orig.tar.gz: obs-studio-32.0.4-sources/frontend/cmake/ui-utility.cmake <==
target_sources(
  obs-studio
  PRIVATE
    utility/AdvancedOutput.cpp
    utility/AdvancedOutput.hpp
    utility/BaseLexer.hpp
    utility/BasicOutputHandler.cpp
    utility/BasicOutputHandler.hpp
    utility/CrashHandler.cpp
    utility/CrashHandler.hpp
    utility/FFmpegCodec.cpp
    utility/FFmpegCodec.hpp
    utility/FFmpegFormat.cpp
    utility/FFmpegFormat.hpp
    utility/FFmpegShared.hpp
    utility/GoLiveAPI_CensoredJson.cpp
    utility/GoLiveAPI_CensoredJson.hpp
    utility/GoLiveAPI_Network.cpp
    utility/GoLiveAPI_Network.hpp
    utility/GoLiveAPI_PostData.cpp
    utility/GoLiveAPI_PostData.hpp
    utility/MissingFilesModel.cpp
    utility/MissingFilesModel.hpp
    utility/MissingFilesPathItemDelegate.cpp
    utility/MissingFilesPathItemDelegate.hpp
    utility/MultitrackVideoError.cpp
    utility/MultitrackVideoError.hpp
    utility/MultitrackVideoOutput.cpp
    utility/MultitrackVideoOutput.hpp
    utility/NativeEventFilter.hpp
    utility/OBSCanvas.cpp
    utility/OBSCanvas.hpp
    utility/OBSEventFilter.hpp
    utility/OBSProxyStyle.cpp
    utility/OBSProxyStyle.hpp
    utility/OBSTheme.hpp
    utility/OBSThemeVariable.hpp
    utility/OBSTranslator.cpp
    utility/OBSTranslator.hpp
    utility/QuickTransition.cpp
    utility/QuickTransition.hpp
    utility/RemoteTextThread.cpp
    utility/RemoteTextThread.hpp
    utility/RemuxEntryPathItemDelegate.cpp
    utility/RemuxEntryPathItemDelegate.hpp
    utility/RemuxQueueModel.cpp
    utility/RemuxQueueModel.hpp
    utility/RemuxWorker.cpp
    utility/RemuxWorker.hpp
    utility/SceneRenameDelegate.cpp
    utility/SceneRenameDelegate.hpp
    utility/ScreenshotObj.cpp
    utility/ScreenshotObj.hpp
    utility/SettingsEventFilter.hpp
    utility/SimpleOutput.cpp
    utility/SimpleOutput.hpp
    utility/StartMultiTrackVideoStreamingGuard.hpp
    utility/SurfaceEventFilter.hpp
    utility/VCamConfig.hpp
    utility/VolumeMeterTimer.cpp
    utility/VolumeMeterTimer.hpp
    utility/audio-encoders.cpp
    utility/audio-encoders.hpp
    utility/display-helpers.hpp
    utility/item-widget-helpers.cpp
    utility/item-widget-helpers.hpp
    utility/models/multitrack-video.hpp
    utility/obf.c
    utility/obf.h
    utility/platform.hpp
    utility/system-info.hpp
    utility/undo_stack.cpp
    utility/undo_stack.hpp
)

==> obs-studio_32.1.0~rc2.orig.tar.gz: obs-studio-32.1.0-rc2-sources/frontend/cmake/ui-utility.cmake <==
target_sources(
  obs-studio
  PRIVATE
    utility/AdvancedOutput.cpp
    utility/AdvancedOutput.hpp
    utility/BaseLexer.hpp
    utility/BasicOutputHandler.cpp
    utility/BasicOutputHandler.hpp
    utility/CrashHandler.cpp
    utility/CrashHandler.hpp
    utility/FFmpegCodec.cpp
    utility/FFmpegCodec.hpp
    utility/FFmpegFormat.cpp
    utility/FFmpegFormat.hpp
    utility/FFmpegShared.hpp
    utility/GoLiveAPI_CensoredJson.cpp
    utility/GoLiveAPI_CensoredJson.hpp
    utility/GoLiveAPI_Network.cpp
    utility/GoLiveAPI_Network.hpp
    utility/GoLiveAPI_PostData.cpp
    utility/GoLiveAPI_PostData.hpp
    utility/MissingFilesModel.cpp
    utility/MissingFilesModel.hpp
    utility/MissingFilesPathItemDelegate.cpp
    utility/MissingFilesPathItemDelegate.hpp
    utility/MultitrackVideoError.cpp
    utility/MultitrackVideoError.hpp
    utility/MultitrackVideoOutput.cpp
    utility/MultitrackVideoOutput.hpp
    utility/NativeEventFilter.hpp
    utility/OBSCanvas.cpp
    utility/OBSCanvas.hpp
    utility/OBSEventFilter.hpp
    utility/OBSProxyStyle.cpp
    utility/OBSProxyStyle.hpp
    utility/OBSTheme.hpp
    utility/OBSThemeVariable.hpp
    utility/OBSTranslator.cpp
    utility/OBSTranslator.hpp
    utility/PreviewProgramSizeObserver.cpp
    utility/PreviewProgramSizeObserver.hpp
    utility/QuickTransition.cpp
    utility/QuickTransition.hpp
    utility/RemoteTextThread.cpp
    utility/RemoteTextThread.hpp
    utility/RemuxEntryPathItemDelegate.cpp
    utility/RemuxEntryPathItemDelegate.hpp
    utility/RemuxQueueModel.cpp
    utility/RemuxQueueModel.hpp
    utility/RemuxWorker.cpp
    utility/RemuxWorker.hpp
    utility/SceneRenameDelegate.cpp
    utility/SceneRenameDelegate.hpp
    utility/ScreenshotObj.cpp
    utility/ScreenshotObj.hpp
    utility/SettingsEventFilter.hpp
    utility/SimpleOutput.cpp
    utility/SimpleOutput.hpp
    utility/StartMultiTrackVideoStreamingGuard.hpp
    utility/SurfaceEventFilter.hpp
    utility/VCamConfig.hpp
    utility/audio-encoders.cpp
    utility/audio-encoders.hpp
    utility/display-helpers.hpp
    utility/item-widget-helpers.cpp
    utility/item-widget-helpers.hpp
    utility/models/multitrack-video.hpp
    utility/obf.c
    utility/obf.h
    utility/platform.hpp
    utility/system-info.hpp
    utility/undo_stack.cpp
    utility/undo_stack.hpp
)
